Functions
- for_
each_ child - Visit each direct child of a node via callback — zero allocation.
- node_
children - Collect all direct child nodes of a given node.
Prefer
for_each_childin hot paths to avoid Vec allocation.
for_each_child in hot paths to avoid Vec allocation.